## Installation (Instalação)

- [English](https://github.com/rzellem/EXOTIC/raw/main/Documentation/English)

- [Português do Brasil](https://github.com/rzellem/EXOTIC/raw/main/Documentation/Brazilian_Portuguese)

## Sample Data (Amostra)

- [HAT-P-32b](https://github.com/rzellem/EXOTIC_sampledata)

A resulting lightcurve from the sample dataset is shown below:

![Lightcurve graph showing relative flux versus phase with error bars and interpolated curve.](https://github.com/rzellem/EXOTIC/raw/main/Documentation/Images/HAT-P-32bExample.png)